@@ -1,7 +1,6 @@
 # encoding: utf-8
-require 'spec_helper'
-
-describe Warden::Config do
+# frozen_string_literal: true
+RSpec.describe Warden::Config do
 
   before(:each) do
     @config = Warden::Config.new
@@ -9,40 +8,40 @@ describe Warden::Config do
 
   it "should behave like a hash" do
     @config[:foo] = :bar
-    @config[:foo].should == :bar
+    expect(@config[:foo]).to eq(:bar)
   end
 
   it "should provide hash accessors" do
     @config.failure_app = :foo
-    @config[:failure_app].should == :foo
+    expect(@config[:failure_app]).to eq(:foo)
     @config[:failure_app] = :bar
-    @config.failure_app.should == :bar
+    expect(@config.failure_app).to eq(:bar)
   end
 
   it "should allow to read and set default strategies" do
     @config.default_strategies :foo, :bar
-    @config.default_strategies.should == [:foo, :bar]
+    expect(@config.default_strategies).to eq([:foo, :bar])
   end
 
   it "should allow to silence missing strategies" do
     @config.silence_missing_strategies!
-    @config.silence_missing_strategies?.should be_true
+    expect(@config.silence_missing_strategies?).to eq(true)
   end
 
   it "should set the default_scope" do
-    @config.default_scope.should == :default
+    expect(@config.default_scope).to eq(:default)
     @config.default_scope = :foo
-    @config.default_scope.should == :foo
+    expect(@config.default_scope).to eq(:foo)
   end
 
   it "should merge given options on initialization" do
-    Warden::Config.new(:foo => :bar)[:foo].should == :bar
+    expect(Warden::Config.new(:foo => :bar)[:foo]).to eq(:bar)
   end
 
   it "should setup defaults with the scope_defaults method" do
     c = Warden::Config.new
     c.scope_defaults :foo, :strategies => [:foo, :bar], :store => false
-    c.default_strategies(:scope => :foo).should == [:foo, :bar]
-    c.scope_defaults(:foo).should == {:store => false}
+    expect(c.default_strategies(:scope => :foo)).to eq([:foo, :bar])
+    expect(c.scope_defaults(:foo)).to eq(store: false)
   end
 end
